#
# Copyright (C) 2018  FreeIPA Contributors see COPYING for license
#

"""
This ALT Linux base platform module exports platform related constants.
"""

# Fallback to default path definitions
from ipaplatform.base.constants import BaseConstantsNamespace, User, Group

__all__ = ("constants", "User", "Group")


class ALTLinuxConstantsNamespace(BaseConstantsNamespace):
    DEFAULT_SHELL = "/bin/bash"
    GSSPROXY_USER = User("_gssproxy")
    HTTPD_USER = User("apache2")
    HTTPD_GROUP = Group("apache2")
    ODS_USER = User("_opendnssec")
    ODS_GROUP = Group("_opendnssec")
    SSSD_USER = User("_sssd")
    NAMED_DATA_DIR = "/var/lib/bind/data/"
    NAMED_ZONE_COMMENT = "//"
    NAMED_RNDC_CONF_COMMENT = ""
    # ntpd init variable used for daemon options
    NTPD_OPTS_VAR = "NTPD_ARGS"
    NAMED_OPENSSL_ENGINE = "pkcs11"
    NAMED_OPTIONS_VAR = "EXTRAOPTIONS"
    # quote used for daemon options
    NTPD_OPTS_QUOTE = '"'
    HTTPD_IPA_MODULES = [
        "ssl",
        "auth_gssapi",
        "rewrite",
        "filter",
        "deflate",
        "headers",
        "authn_core",
        "authz_user",
        "expires",
        "lookup_identity",
        "session",
        "session_cookie",
        "proxy_ajp",
        "proxy_http",
        "proxy",
    ]
    HTTPD_IPA_CONFL_MODULES = [
        "nss",
    ]
    PASSWORD_QUALITY_LIB = None
    SELINUX_MCS_MAX = 15
    SELINUX_MLS_MAX = 3
    SELINUX_USER_REGEX = r"^[a-zA-Z][a-zA-Z0-9_\.]*$"
    SELINUX_USERMAP_DEFAULT = "generic_u:s0-s3:c0.c15"
    SELINUX_USERMAP_ORDER = (
        "generic_u3:s3-s3:c0.c15"
        "$generic_u2:s2-s3:c0.c15"
        "$generic_u1:s1-s3:c0.c15"
        "$officer_u:s0-s3:c0.c15"
        "$generic_u:s0-s3:c0.c15"
    )
    SECURE_NFS_VAR = None


constants = ALTLinuxConstantsNamespace()
